<template>
  <j-modal
    :title="title"
    :width="1500"
    :visible="visible"
    :confirmLoading="confirmLoading"
    switchFullscreen
    centered
    :mask-closable="false"
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭"
  >

    <a-spin :spinning="spinning">
      <a-form-model
        ref="form"
        :model="model"
        :rules="validatorRules"
        :labelCol="labelCol"
        :wrapperCol="wrapperCol"
      >
        <a-row :gutter="24">
          <j-vxe-table
            ref="editableDetailTable"
            :rowNumber="true"
            :rowSelection="true"
            :bordered="true"
            :alwaysEdit="true"
            :toolbar="true"
            keep-source
            :height="300"
            :loading="detail.loading"
            :dataSource="detail.dataSource"
            :columns="detail.columns"
            style="margin-top: 8px;"
          />
        </a-row>
      </a-form-model>
    </a-spin>
  </j-modal>
</template>

<script>
import { getAction, httpAction } from '@/api/manage'
import { JVxeTableModelMixin } from '@/mixins/JVxeTableModelMixin.js'
import { JVXETypes } from '@/components/jeecg/JVxeTable'

export default {
  name: 'EamSparePartIntoModal',
  mixins: [JVxeTableModelMixin],
  components: {},
  data() {
    return {
      title: '操作',
      visible: false,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 6 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 15 }
      },
      confirmLoading: false,
      spinning: false,
      disabled: false,
      validatorRules: {},
      url: {
        add: '/eam/eamSparePartInventory/add',
        edit: '/eam/eamSparePartInventory/edit',
      },
      detail: {
        loading: false,
        dataSource: [],
        columns: [
          {
            title: '来源类型',
            key: 'sparePartIntoType',
            type: JVXETypes.hidden,
            width: '12%',
            align: 'center',
            defaultValue: '1',
            validateRules: [
              { required: true, message: '备件不能为空！' }
            ]
          },
          {
            title: '备件',
            key: 'sparePartId',
            type: JVXETypes.select,
            width: '12%',
            align: 'center',
            dictCode: 'eam_spare_parts,part_name,id, del_flag!=\'1\'',
            validateRules: [
              { required: true, message: '备件不能为空！' }
            ]
          },
          {
            title: '批次号',
            key: 'batchNum',
            type: JVXETypes.input,
            width: '10%',
            align: 'center',
            validateRules: [
              { required: true, message: '批次号不能为空！' }
            ]
          },
          {
            title: '数量',
            key: 'inventory',
            type: JVXETypes.inputNumber,
            width: '10%',
            align: 'center',
            validateRules: [
              { required: true, message: '数量不能为空！' }
            ]
          },
          {
            title: '出厂日期(生产日期)',
            key: 'manufactureDate',
            type: JVXETypes.datetime,
            width: '16%',
            align: 'center',
            validateRules: [
              { required: false, message: '出厂日期(生产日期)不能为空！' }
            ]
          },
          {
            title: '供应商',
            key: 'supplier',
            type: JVXETypes.textarea,
            width: '15%',
            align: 'center',
            validateRules: [
              { required: false, message: '供应商不能为空！' }
            ]
          },
          {
            title: '截止有效期',
            key: 'expirationOfValidity',
            type: JVXETypes.datetime,
            width: '16%',
            align: 'center',
            validateRules: [
              { required: false, message: '截止有效期不能为空！' }
            ]
          },
          {
            title: '存放位置',
            key: 'location',
            type: JVXETypes.textarea,
            width: '13%',
            align: 'center',
            validateRules: [
              { required: false, message: '存放位置不能为空！' }
            ]
          },
        ]
      }
    }
  },
  created() {
  },
  methods: {
    add() {
      this.model = {}
      this.detail.dataSource = []
      this.visible = true
    },


    async handleOk() {
      const that = this
      let errMap = await that.$refs.editableDetailTable.validateTable()
      if (errMap) {
        this.$message.warning('数据校验失败！')
        return
      }

      let tableData = that.$refs.editableDetailTable.getTableData()
      if (tableData.length == 0) {
        this.$message.warning('请选择备件入库明细！')
        return
      }

      for (var i = 0; i < tableData.length; i++) {
        let count = 0;
        tableData.forEach(row => {
          if (row.sparePartId === tableData[i].sparePartId) {
            count++;
          }
        });
        // 如果重复次数大于1，说明有重复
        if (count > 1) {
          this.$message.warning('选择的备件不能重复！')
          return
        }
      }
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          let tableData = that.$refs.editableDetailTable.getTableData()
          let removeData = that.$refs.editableDetailTable.getDeleteData()
          that.model.eamSparePartInventories = [...tableData]
          that.model.removeDetailList = [...removeData]

          that.confirmLoading = that.spinning = true
          let httpurl = ''
          let method = ''
          if (!this.model.id) {
            httpurl += this.url.add
            method = 'post'
          } else {
            httpurl += this.url.edit
            method = 'put'
          }
          httpAction(httpurl, this.model, method).then((res) => {

            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok')
              that.close()
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = that.spinning = false
          })
        } else {
          return false
        }
      })
    },



    handleCancel() {
      this.close()
    },

    close() {
      this.$emit('close')
      this.visible = false
      this.$refs.form.clearValidate()
    }
  }
}
</script>

<style lang="less" scoped>
</style>